UpdatGlobalOptions class

Used to define options that can be accessed globally by Updat. Properties are static, so there is no need to instantiate this.

Constructors

UpdatGlobalOptions()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

downloadReleaseHeaders ↔ Map<String, String>
A Map of HTTP headers injected into the downloadRelease GET request made by Updat. If you need to authenticate to your Git server with a personal access token, you are able to define that here.
getter/setter pair